set more off
capture log close
clear
set mem 1g

local c_date = c(current_date)
local c_date = subinstr("`c_date'", " ", "_", .)
log using ../log/domains_`c_date', text replace

* PROGRAMS;

* imports a correlation matrix and brings it in the form to export it - i.e. adds p-values, number of obs and average correlation
capture program drop corr_matrix
program define corr_matrix
	local nobs = `2'
	matrix define R = `1'
	matrix A = J(2*rowsof(R)+2,colsof(R),.)
	local rows = 2*rowsof(R)
	local cols = colsof(R)

	forval i = 1/`rows' {
		forval j = 1/`cols' {
			* odd - copy the value in R
			if (`j'<`i' & mod(`i', 2)) { 
				matrix A[`i',`j'] = R[(`i'+1)/2,`j'] 
				}
			* even - t-stat
			if (`j'<`i' & !mod(`i', 2)) { 
				matrix A[`i',`j'] = min(tprob(`nobs'-2, R[`i'/2,`j']*sqrt(`nobs'-2)/ sqrt(1-R[`i'/2,`j']^2)),1) 
				* p-values formula from pwcorr.ado
				}
			
			if (`j'>=`i'/2) {
				matrix A[`i',`j']=.
				}
			}
	}
	local nvars = rowsof(R)
	local sum_corr = 0
	local count = 0
	forval i = 1/`nvars' {
		forval j = 1/`cols' {
			if (`i'>`j') {
				local count = `count'+1
				local sum_corr = `sum_corr' + R[`i',`j']
				}
			}
		}

	local mean_corr = `sum_corr'/`count'
	matrix A[2*rowsof(R)+1,1] = `nobs'
	matrix A[2*rowsof(R)+2,1] = `mean_corr' 
	matrix final = A[3..`rows'+2, 1..`cols'-1]
end

* program to compute average correlation
capture program drop mean_corr
program define mean_corr, rclass
	matrix define R = `1'
	local nvars = rowsof(R)
	local cols = colsof(R)
	local sum_corr = 0
	local count = 0
		forval i = 1/`nvars' {
			forval j = 1/`cols' {
				if (`i'>`j') {
					local count = `count'+1
					local sum_corr = `sum_corr' + R[`i',`j']
					}
				}
			}
	local mean = `sum_corr'/`count'
	return scalar mean = `mean'
end

* ***************************************************
* Analysis starts here
use ../dta/sample_080911.dta, replace

gen any_std = (std_days>0)
gen any_ltd = (ltd_days>0)

gen wage_high = 1 if wage_amt_hr>72000
replace wage_high = 0 if wage_amt_hr<36000
gen age_old = 1 if age>=55
replace age_old = 0 if age<=35
gen no_alcoa_cont = !alcoa_cont
gen salaried = !hourly

* ***********************************************************
* TABLE 1 PANEL A & PANEL B
tabstat age wage_amt_hr tenure_hr female white hourly union single family_size, stats(mean sd p5 p95) columns(stat)
tabstat total rx_total dental_total std_days any_std ltd_days any_ltd rfree_cont total_emp_cont, stats(mean sd p5 p95) columns(stat)

* ***********************************************************
* TABLE 3A PANEL A - SPEARMAN
spearman hi_ord drug_ord dental_ord stdi_ord ltd_ord rfree_cont
matrix define CR = r(Rho)
local nobs = r(N)
corr_matrix CR `nobs'
matrix colnames final = "HI" "Drug" "Dental" "STDI" "LTDI"
matrix rownames final = "Drug" "p-value" "Dental" "p-value" "STDI" "p-value" "LTDI" "p-value" "401k" "p-value" "N" "Avg" 
matrix list final, format(%9.3f)

* ***********************************************************
* TABLE 3A PANEL C - MULTIVARIATE REGRESSION, ONLY MENU FE
qui: xi: sureg (hi_ord drug_ord dental_ord stdi_ord ltd_ord rfree_cont = i.allmenu), corr notable
foreach var in hi_ord drug_ord dental_ord stdi_ord ltd_ord rfree_cont {
	predict `var'_resid , residuals equation(`var')
	}
local nobs=e(N)
matrix CR = corr(e(Sigma))
corr_matrix CR `nobs'
matrix colnames final = "HI" "Drug" "Dental" "STDI" "LTDI"
matrix rownames final = "Drug" "p-value" "Dental" "p-value" "STDI" "p-value" "LTDI" "p-value" "401k" "p-value" "N" "Avg" 
matrix list final, format(%9.3f)

* ***********************************************************
* TABLE 4(B) - BY X'S - menu FE
local i = 0
matrix define results = J(21,9,.)

foreach var of varlist single new_hired wage_high no_alcoa_cont rebalance age_old salaried {
	* var = 1
	qui: xi: sureg (hi_ord drug_ord dental_ord stdi_ord ltd_ord rfree_cont = i.allmenu) if `var'==1, corr notable
	local nobs1=e(N)
	matrix CR1 = corr(e(Sigma))
	mean_corr CR1
	* avg correlation
	matrix results[3*`i'+1,1]=r(mean)
	* HI & drug
	matrix results[3*`i'+1,2]=CR1[1,2]
	* HI & DI
	matrix results[3*`i'+1,3]=CR1[1,4]
	* 401(k) & HI
	matrix results[3*`i'+1,4]=CR1[1,6]
		matrix results[3*`i'+1,5]=CR1[2,6]
			matrix results[3*`i'+1,6]=CR1[3,6]
				matrix results[3*`i'+1,7]=CR1[4,6]
					matrix results[3*`i'+1,8]=CR1[5,6]
	* nobs
	matrix results[3*`i'+1,9]=`nobs1'
	
	* var = 0
	qui: xi: sureg (hi_ord drug_ord dental_ord stdi_ord ltd_ord rfree_cont = i.allmenu) if `var'==0, corr notable
	local nobs2=e(N)
	matrix CR2 = corr(e(Sigma))
	mean_corr CR2
	* avg correlation
	matrix results[3*`i'+2,1]=r(mean)
	* HI & drug
	matrix results[3*`i'+2,2]=CR2[1,2]
	* HI & DI
	matrix results[3*`i'+2,3]=CR2[1,4]
	* 401(k) & HI
	matrix results[3*`i'+2,4]=CR2[1,6]
		matrix results[3*`i'+2,5]=CR2[2,6]
			matrix results[3*`i'+2,6]=CR2[3,6]
				matrix results[3*`i'+2,7]=CR2[4,6]
					matrix results[3*`i'+2,8]=CR2[5,6]	
	* nobs
	matrix results[3*`i'+2,9]=`nobs2'
	
	local i=`i'+1
}
matrix colnames results = "Avg_corr" "HI-Rx" "HI-STDI" "401k-HI" "401k-Drug" "401k-Dental" "401k-STDI" "401k-LTDI" "N"
matrix rownames results = "Single" "Non-single" "-" "Newly-Hired" "Not" "-" "Top-wage" "Low-wage" "-" "No-Co-Stock" "Co-stock" "-" "Rebalance" "Not" "-" "Over-55" "Under-35" "-" "Salaried" "Hourly" "-"
matrix list results

* ***********************************************************
* TABLE 6 - PANEL B

local i = 0
matrix define results = J(7,9,.)

gen housing_sample = 1 if equity_share !=.
recode avl_equity (0/50000 = 1 "1-less than 50k") (50000/150000 = 2 "2-50k to 150k") (150000/1000000000 = 3 "3-more than 150k") if housing_sample==1, gen(avl_equity_recode)

foreach condition in "1==1" "housing_sample==1" "avl_equity_recode==1" "avl_equity_recode==2" "avl_equity_recode==3" "constr_401k==0" "constr_401k==1" {
	local i = `i' + 1
	qui: xi: sureg (hi_ord drug_ord dental_ord stdi_ord ltd_ord rfree_cont = i.allmenu) if `condition', corr notable
	local nobs1=e(N)
	matrix CR1 = corr(e(Sigma))
	mean_corr CR1
	* avg correlation
	matrix results[`i',1]=r(mean)
	* HI & drug
	matrix results[`i',2]=CR1[1,2]
	* HI & DI
	matrix results[`i',3]=CR1[1,4]
	* 401(k) & HI
	matrix results[`i',4]=CR1[1,6]
	matrix results[`i',5]=CR1[2,6]
	matrix results[`i',6]=CR1[3,6]
	matrix results[`i',7]=CR1[4,6]
	matrix results[`i',8]=CR1[5,6]
	* nobs
	matrix results[`i',9]=`nobs1'
}

matrix colnames results = "Avg_corr" "HI-Rx" "HI-STDI" "401k-HI" "401k-Drug" "401k-Dental" "401k-STDI" "401k-LTDI" "N"
matrix rownames results = "WholeSample" "HousingSample" "Eq-less-50k" "Eq-50-150" "Eq-above-150" "401k-not-const" "401k-constr"
matrix list results, format(%9.3g)

* ***********************************************************
* TABLE 7 - R-SQUARED

matrix define results = J(5,6,.)
matrix colnames results = "HI" "RX" "Dental" "STDI" "LTDI" "401k"
* columns are in order HI, RX, Dental, STDI, LTDI, 401k
* partial out menu fixed effects
* X's are in order - choices in other domains, predicted and realized risk, demographics, choices in less related domains, all of the above
matrix rownames results = "Other-choices" "Predicted-Realized-Risk" "Demographics" "Less-Related-domains" "All" 
global demog = "age age_sq female white hourly tenure_hr wage_amt_hr single"
global predicted_risk = "total_xb rx_total_xb dental_total_xb std_days_xb ltd_days_xb"
global realized_risk = "total rx_total dental_total std_days ltd_days"

* predict risk
mkspline age_spline = age, cubic nknots(7)
mkspline wage_spline = wage_amt_hr, cubic nknots(7)
mkspline tenure_spline = tenure_hr, cubic nknots(4)
gen age_female = age*female
gen age_single = age*single
gen age_hourly = age*hourly
gen over65 = (age>65)

foreach var in total rx_total dental_total std_days ltd_days {
	qui xi: reg `var' *spline* female hourly  white union single family_size age_single age_female age_hourly over65 i.state_loc
	predict `var'_xb, xb
}
* partial out menuFE 
qui: areg hi_ord, absorb(allmenu)
predict hi_resid, residuals

qui: areg drug_ord, absorb(allmenu)
predict drug_resid, residuals

qui: areg dental_ord, absorb(allmenu)
predict dental_resid, residuals

qui: areg stdi_ord, absorb(allmenu)
predict stdi_resid, residuals

qui: areg ltd_ord, absorb(allmenu)
predict ltd_resid, residuals

qui: areg rfree_cont, absorb(allmenu)
predict rfree_resid, residuals

qui: areg rs_fam, absorb(allmenu)
predict rs_fam_resid, residuals

gen age_sq = age*age

foreach var of varlist $demog $predicted_risk $realized_risk {
	qui: areg `var', absorb(allmenu)
	predict `var'_resid, residuals
	}

global demog_resid = "age_resid age_sq_resid female_resid white_resid hourly_resid tenure_hr_resid wage_amt_hr_resid single_resid"
global predicted_risk_resid = "total_xb_resid rx_total_xb_resid dental_total_xb_resid std_days_xb_resid ltd_days_xb_resid"
global realized_risk_resid = "total_resid rx_total_resid dental_total_resid std_days_resid ltd_days_resid"

* COLUMN 1 - Health insurance 
* choices in other domains, predicted and realized risk, demographics, choices in less related domains, all of the above
qui: reg hi_resid drug_resid dental_resid stdi_resid ltd_resid rfree_resid
matrix results[1,1] = e(r2_a)
qui: reg  hi_resid $realized_risk_resid $predicted_risk_resid rs_fam_resid
matrix results[2,1] = e(r2_a)
qui: reg hi_resid $demog_resid
matrix results[3,1] = e(r2_a)
* take out drug
qui: reg hi_resid dental_resid stdi_resid ltd_resid rfree_resid
matrix results[4,1] = e(r2_a)
qui: reg hi_resid drug_resid dental_resid stdi_resid ltd_resid rfree_resid $realized_risk_resid $predicted_risk_resid $demog_resid rs_fam_resid
matrix results[5,1] = e(r2_a)

* COLUMN 2 - drug insurance
* choices in other domains, predicted and realized risk, demographics, choices in less related domains, all of the above
qui: reg drug_resid hi_resid dental_resid stdi_resid ltd_resid rfree_resid
matrix results[1,2] = e(r2_a)
qui: reg  drug_resid $realized_risk_resid $predicted_risk_resid rs_fam_resid
matrix results[2,2] = e(r2_a)
qui: reg drug_resid $demog_resid
matrix results[3,2] = e(r2_a)
* take out HI
qui: reg drug_resid dental_resid stdi_resid ltd_resid rfree_resid
matrix results[4,2] = e(r2_a)
qui: reg drug_resid hi_resid dental_resid stdi_resid ltd_resid rfree_resid $realized_risk_resid $predicted_risk_resid $demog_resid rs_fam_resid
matrix results[5,2] = e(r2_a)

* Column 3 - dental insurance
* choices in other domains, predicted and realized risk, demographics, choices in less related domains, all of the above
qui: reg dental_resid drug_resid hi_resid stdi_resid ltd_resid rfree_resid
matrix results[1,3] = e(r2_a)
qui: reg  dental_resid $realized_risk_resid $predicted_risk_resid rs_fam_resid
matrix results[2,3] = e(r2_a)
qui: reg dental_resid $demog_resid
matrix results[3,3] = e(r2_a)
* take out drug
qui: reg dental_resid hi_resid stdi_resid ltd_resid rfree_resid
matrix results[4,3] = e(r2_a)
qui: reg dental_resid drug_resid hi_resid stdi_resid ltd_resid rfree_resid $realized_risk_resid $predicted_risk_resid $demog_resid rs_fam_resid
matrix results[5,3] = e(r2_a)

* Column 4 - STD insurance
* choices in other domains, predicted and realized risk, demographics, choices in less related domains, all of the above
qui: reg stdi_resid dental_resid drug_resid hi_resid ltd_resid rfree_resid
matrix results[1,4] = e(r2_a)
qui: reg stdi_resid $realized_risk_resid $predicted_risk_resid rs_fam_resid
matrix results[2,4] = e(r2_a)
qui: reg stdi_resid $demog_resid
matrix results[3,4] = e(r2_a)
* take out ltd
qui: reg stdi_resid hi_resid drug_resid dental_resid rfree_resid
matrix results[4,4] = e(r2_a)
qui: reg stdi_resid hi_resid drug_resid dental_resid ltd_resid rfree_resid $realized_risk_resid $predicted_risk_resid $demog_resid rs_fam_resid
matrix results[5,4] = e(r2_a)

* COLUMN 5 - LTD insurance
* choices in other domains, predicted and realized risk, demographics, choices in less related domains, all of the above
qui: reg ltd_resid stdi_resid dental_resid drug_resid hi_resid rfree_resid
matrix results[1,5] = e(r2_a)
qui: reg ltd_resid $realized_risk_resid $predicted_risk_resid rs_fam_resid
matrix results[2,5] = e(r2_a)
qui: reg ltd_resid $demog_resid
matrix results[3,5] = e(r2_a)
* take out stdi
qui: reg ltd_resid hi_resid drug_resid dental_resid rfree_resid
matrix results[4,5] = e(r2_a)
qui: reg ltd_resid stdi_resid hi_resid drug_resid dental_resid rfree_resid $realized_risk_resid $predicted_risk_resid $demog_resid rs_fam_resid
matrix results[5,5] = e(r2_a)

* Column 6 - 401k
* choices in other domains, predicted and realized risk, demographics, choices in less related domains, all of the above
qui: reg  rfree_resid ltd_resid stdi_resid dental_resid drug_resid hi_resid
matrix results[1,6] = e(r2_a)
qui: reg  rfree_resid $realized_risk_resid $predicted_risk_resid rs_fam_resid
matrix results[2,6] = e(r2_a)
qui: reg  rfree_resid $demog_resid
matrix results[3,6] = e(r2_a)
* take out HI
qui: reg  rfree_resid stdi_resid ltd_resid drug_resid dental_resid
matrix results[4,6] = e(r2_a)
qui: reg  rfree_resid ltd_resid stdi_resid hi_resid drug_resid dental_resid $realized_risk_resid $predicted_risk_resid $demog_resid rs_fam_resid
matrix results[5,6] = e(r2_a)
matrix list results

* TABLE 5 - PANEL B
* ***********************************************************
* baseline, discretize 401k, control for coverage tier, largest pricing menu, opt-out and hmo, 
* include 401k non-contributors, include not offered LTD, exclude Select 1
* only new hires, exclude defaulters

matrix define results = J(10,5,.)
matrix colnames results = "N" "Avg" "HI-RX" "HI-STDI" "HI-401k" 
matrix rownames results = "Baseline" "Discretize-401k" "Coverage-tier-FE" "Largest-menu" "include-opt-out-hmo" "include-not-401k-cont" "no-ltd-offered" "exclude-select1" "only-new-hires" "no-default"

* 1 - baseline results from table 3b
qui: xi: sureg (hi_ord drug_ord dental_ord stdi_ord ltd_ord rfree_cont = i.allmenu), corr notable
local nobs=e(N)
matrix CR = corr(e(Sigma))
matrix results[1,1] = `nobs'
matrix results[1,2] = (CR[1,2] + CR[1,3] + CR[1,4] + CR[1,5] + CR[1,6] + CR[2,3] + CR[2,4] + CR[2,5] + CR[2,6] + CR[3,4] + CR[3,5] + CR[3,6] + CR[4,5] + CR[4,6] + CR[5,6])/15
matrix results[1,3] = CR[1,2]
matrix results[1,4] = CR[1,4]
matrix results[1,5] = CR[1,6]
matrix drop CR

* 2 - discretize 401k - 20% brackets of investment
recode rfree_cont (min/.01 = 1) (.01/.99 = 2) (.99/max = 3), gen(rfree_recode)
qui: xi: sureg (hi_ord drug_ord dental_ord stdi_ord ltd_ord rfree_recode = i.allmenu), corr notable
local nobs=e(N)
matrix CR = corr(e(Sigma))
matrix results[2,1] = `nobs'
matrix results[2,2] = (CR[1,2] + CR[1,3] + CR[1,4] + CR[1,5] + CR[1,6] + CR[2,3] + CR[2,4] + CR[2,5] + CR[2,6] + CR[3,4] + CR[3,5] + CR[3,6] + CR[4,5] + CR[4,6] + CR[5,6])/15
matrix results[2,3] = CR[1,2]
matrix results[2,4] = CR[1,4]
matrix results[2,5] = CR[1,6]
matrix drop CR

* 3 - coverage tier FE
qui: xi: sureg (hi_ord drug_ord dental_ord stdi_ord ltd_ord rfree_cont = i.allmenu i.covg_tierrecode), corr notable
local nobs=e(N)
matrix CR = corr(e(Sigma))
matrix results[3,1] = `nobs'
matrix results[3,2] = (CR[1,2] + CR[1,3] + CR[1,4] + CR[1,5] + CR[1,6] + CR[2,3] + CR[2,4] + CR[2,5] + CR[2,6] + CR[3,4] + CR[3,5] + CR[3,6] + CR[4,5] + CR[4,6] + CR[5,6])/15
matrix results[3,3] = CR[1,2]
matrix results[3,4] = CR[1,4]
matrix results[3,5] = CR[1,6]
matrix drop CR
matrix list results

* 4 - only largest pricing menu
qui: xi: sureg (hi_ord) (drug_ord) (dental_ord) (stdi_ord) (ltd_ord) (rfree_cont) if allmenu == 52481, corr notable
local nobs=e(N)
matrix CR = corr(e(Sigma))
matrix results[4,1] = `nobs'
matrix results[4,2] = (CR[1,2] + CR[1,3] + CR[1,4] + CR[1,5] + CR[1,6] + CR[2,3] + CR[2,4] + CR[2,5] + CR[2,6] + CR[3,4] + CR[3,5] + CR[3,6] + CR[4,5] + CR[4,6] + CR[5,6])/15
matrix results[4,3] = CR[1,2]
matrix results[4,4] = CR[1,4]
matrix results[4,5] = CR[1,6]
matrix drop CR

* ***********************************************************
* Different samples
* ***********************************************************
* 5 - include opt-out and HMO
* 6 - include 401k non-contributors
* 7 - include LTD not offered
* 8 - exclude Select 1
* 9 - only new hires 
* 10 - exclude possible default options

* 8 - exclude Select 1
qui: xi: sureg (hi_ord drug_ord dental_ord stdi_ord ltd_ord rfree_cont = i.allmenu) if hi_ord!=1, corr notable
local nobs=e(N)
matrix CR = corr(e(Sigma))
matrix results[8,1] = `nobs'
matrix results[8,2] = (CR[1,2] + CR[1,3] + CR[1,4] + CR[1,5] + CR[1,6] + CR[2,3] + CR[2,4] + CR[2,5] + CR[2,6] + CR[3,4] + CR[3,5] + CR[3,6] + CR[4,5] + CR[4,6] + CR[5,6])/15
matrix results[8,3] = CR[1,2]
matrix results[8,4] = CR[1,4]
matrix results[8,5] = CR[1,6]
matrix drop CR

* 9 - new-hires
qui: xi: sureg (hi_ord drug_ord dental_ord stdi_ord ltd_ord rfree_cont = i.allmenu) if new_hired, corr notable
local nobs=e(N)
matrix CR = corr(e(Sigma))
matrix results[9,1] = `nobs'
matrix results[9,2] = (CR[1,2] + CR[1,3] + CR[1,4] + CR[1,5] + CR[1,6] + CR[2,3] + CR[2,4] + CR[2,5] + CR[2,6] + CR[3,4] + CR[3,5] + CR[3,6] + CR[4,5] + CR[4,6] + CR[5,6])/15
matrix results[9,3] = CR[1,2]
matrix results[9,4] = CR[1,4]
matrix results[9,5] = CR[1,6]
matrix drop CR

* 10 - exclude default - 
qui: xi: sureg (hi_ord drug_ord dental_ord stdi_ord ltd_ord rfree_cont = i.allmenu) if !default, corr notable
local nobs=e(N)
matrix CR = corr(e(Sigma))
matrix results[10,1] = `nobs'
matrix results[10,2] = (CR[1,2] + CR[1,3] + CR[1,4] + CR[1,5] + CR[1,6] + CR[2,3] + CR[2,4] + CR[2,5] + CR[2,6] + CR[3,4] + CR[3,5] + CR[3,6] + CR[4,5] + CR[4,6] + CR[5,6])/15
matrix results[10,3] = CR[1,2]
matrix results[10,4] = CR[1,4]
matrix results[10,5] = CR[1,6]
matrix drop CR
matrix list results

* for 5,6,7 we need a different sample
clear
use ../dta/clean_sample_full
gen deviations = hmo_opt_out + non_contrib + ltd_not_offered
tab deviations
keep if deviations < 2

* 5 - include opt-out and HMO - all correlations except for HI, drug
qui: xi: sureg (dental_ord stdi_ord ltd_ord rfree_cont = i.allmenu) if deviations == 0 | hmo_opt_out, corr notable
local nobs=e(N)
matrix CR = corr(e(Sigma))
matrix results[5,1] = `nobs'
matrix results[5,2] = (CR[1,2] + CR[1,3] + CR[1,4] + CR[2,3] + CR[2,4] + CR[3,4])/6
matrix drop CR

* 6 - include 401k non-contrib
qui: xi: sureg (hi_ord drug_ord dental_ord stdi_ord ltd_ord = i.allmenu) if deviations==0 | non_contrib, corr notable
local nobs=e(N)
matrix CR = corr(e(Sigma))
matrix results[6,1] = `nobs'
matrix results[6,2] = (CR[1,2] + CR[1,3] + CR[1,4] + CR[1,5] + CR[2,3] + CR[2,4] + CR[2,5] + CR[3,4] + CR[3,5] + CR[4,5])/10
matrix results[6,3] = CR[1,2]
matrix results[6,4] = CR[1,4]
matrix drop CR

* 7 - include not offered LTD
qui: xi: sureg (hi_ord drug_ord dental_ord stdi_ord rfree_cont = i.allmenu) if deviations==0 | ltd_not_offered, corr notable
local nobs=e(N)
matrix CR = corr(e(Sigma))
matrix results[7,1] = `nobs'
matrix results[7,2] = (CR[1,2] + CR[1,3] + CR[1,4] + CR[1,5] + CR[2,3] + CR[2,4] + CR[2,5] + CR[3,4] + CR[3,5] + CR[4,5])/10
matrix results[7,3] = CR[1,2]
matrix results[7,4] = CR[1,4]
matrix results[7,5] = CR[1,5]
matrix drop CR

matrix list results, format(%9.3g)
matrix drop results

capture log close
